@@ -1210,9 +1210,20 @@ def copy_event(event, user):
         description = event.description,
         timezone = event.timezone,
         type = event.type,
+        group = event.group,
+        image = event.image,
+        start_dt = event.start_dt,
+        end_dt = event.end_dt,
         all_day = event.all_day,
+        on_weekend = event.on_weekend,
+        mark_registration_ended = event.mark_registration_ended,
         private = event.private,
         password = event.password,
+        tags = event.tags,
+        external_url = event.external_url,
+        priority = event.priority,
+        display_event_registrants = event.display_event_registrants,
+        display_registrants_to = event.display_registrants_to,
         allow_anonymous_view = False,
         allow_user_view = event.allow_user_view,
         allow_member_view = event.allow_member_view,
@@ -1224,7 +1235,6 @@ def copy_event(event, user):
         owner_username = user.username,
         status = event.status,
         status_detail = event.status_detail,
-        tags = event.tags,
     )
 
     #copy place
@@ -1268,7 +1278,17 @@ def copy_event(event, user):
             payment_required = old_regconf.payment_required,
             limit = old_regconf.limit,
             enabled = old_regconf.enabled,
+            require_guests_info = old_regconf.require_guests_info,
             is_guest_price = old_regconf.is_guest_price,
+            discount_eligible = old_regconf.discount_eligible,
+            display_registration_stats = old_regconf.display_registration_stats,
+            use_custom_reg_form = old_regconf.use_custom_reg_form,
+            reg_form = old_regconf.reg_form,
+            bind_reg_form_to_conf_only = old_regconf.bind_reg_form_to_conf_only,
+            email = old_regconf.email,
+            send_reminder = old_regconf.send_reminder,
+            reminder_days = old_regconf.reminder_days,
+            registration_email_text = old_regconf.registration_email_text,
         )
         new_regconf.payment_method = old_regconf.payment_method.all()
         new_regconf.save()
@@ -1283,6 +1303,9 @@ def copy_event(event, user):
                 quantity = pricing.quantity,
                 group = pricing.group,
                 price = pricing.price,
+                reg_form = pricing.reg_form,
+                start_dt = pricing.start_dt,
+                end_dt = pricing.end_dt,
                 allow_anonymous = pricing.allow_anonymous,
                 allow_user = pricing.allow_user,
                 allow_member = pricing.allow_member,
